@@ -10,11 +10,11 @@ class FlaUiError(AttributeError):
     ApplicationPidNotFound = "Application with pid {} could not be found"
     ApplicationNameNotFound = "Application with name '{}' could not be found"
     NoElementAttached = "No element attached"
+    ElementNameNotFound = "Name '{}' could not be found in element"
     ElementNameNotEquals = "Name from element '{}' is not equals to '{}'"
     ElementNameDoesNotContainsFromValue = "Name from element '{}' does not contains to '{}'"
     ElementNotClickable = "Element position could not be found because it is hidden."
     ActionNotSupported = "Action not supported"
-    ElementDoesNotExistsAnymore = "Element does not exists"
     ElementExists = "Element '{}' exists"
     ElementVisible = "Element '{}' is visible"
     ElementNotVisible = "Element '{}' is not visible"
